@@ -1,4 +1,4 @@
-#! /usr/bin/perl
+#!/usr/bin/perl -I/tmp/4f/lib/4f
 
 # --------------------------------------------------------------------
 # 4F - Formula for Form Fabrication
@@ -65,15 +65,32 @@ use Data::Dumper;
 	#
 	if ($@) {
 		print "Contnt-Type: text/html\n\n";
-		print $@;
+        $@ =~ s/&/&amp;/g;
+        $@ =~ s/</&lt;/g;
+        $@ =~ s/>/&gt;/g;
+        $@ =~ s/\"/&quot;/g;
+		print "SYSTEM ERR: <PRE>$@</PRE>";
 	}
 
 	#
 	# ǥХåν
 	#
 	if ($ffff->{CONFIG}->{DEBUG} == 1) {
-		print "<hr>";
 		print "<pre>";
-		print Dumper $ffff;
+		print "<hr>ACTION: " . $ffff->{FORM}->{_action};
+		print "<hr>ERROR: "  . Dumper $ffff->{ERROR};
+		print "<hr>DUMP: "   . Dumper $ffff;
 		print "</pre>";
 	}
+__END__
+=head CHANGES
+0.0.3   2002/05/15
+	- 顼 HTML ׽ɲ
+
+0.0.2   2002/05/14
+    - ǥХåˡߤACTIONERROR褻褦ˤ
+      פȸˤΤǡ
+
+0.0.1   2002/05/09
+    - original version
+=cut
