@@ -36,7 +36,7 @@ sub new {
 		#
 		# åϥåɻߤΤ̩
 		#
-		DIGEST_KEY => '4F-SESSION-LIB-DIGEST-KEY' . $ENV{HTTP_USER_AGENT},
+		DIGEST_KEY => 'BALBFTB2JEKLF8O6SX10TVVA1' . $ENV{HTTP_USER_AGENT},
 
 
 		#
